@@ -7,7 +7,7 @@ from django.views.generic import View, TemplateView, CreateView
 from django.views.generic.edit import UpdateView, DeleteView
 from django.http import HttpResponse, HttpResponseRedirect
 from django.contrib.auth.decorators import login_required
-from django.contrib.auth.models import User
+from django.contrib.auth import get_user_model
 from django.contrib import messages
 from django.utils.decorators import method_decorator
 from django.core.urlresolvers import reverse
@@ -16,8 +16,9 @@ from django.utils.timezone import now
 
 import dnstools
 
-from .forms import CreateHostForm, EditHostForm, CreateDomainForm, EditDomainForm
-from .models import Host, Domain
+from .forms import (CreateHostForm, EditHostForm, CreateDomainForm, EditDomainForm,
+                    CreateUpdaterHostConfigForm, EditUpdaterHostConfigForm)
+from .models import Host, Domain, ServiceUpdaterHostConfig
 
 
 class GenerateSecretView(UpdateView):
@@ -88,6 +89,10 @@ class HomeView(TemplateView):
 class StatusView(TemplateView):
     template_name = "main/status.html"
 
+    @method_decorator(login_required)
+    def dispatch(self, *args, **kwargs):
+        return super(StatusView, self).dispatch(*args, **kwargs)
+
     def get_context_data(self, *args, **kwargs):
         context = super(
             StatusView, self).get_context_data(*args, **kwargs)
@@ -96,6 +101,9 @@ class StatusView(TemplateView):
         context['domains_unavailable'] = Domain.objects.filter(available=False).count()
         context['domains_public'] = Domain.objects.filter(public=True).count()
         context['hosts_total'] = Host.objects.count()
+        context['hosts_unavailable'] = Host.objects.filter(available=False).count()
+        context['hosts_abuse'] = Host.objects.filter(abuse=True).count()
+        context['hosts_abuse_blocked'] = Host.objects.filter(abuse_blocked=True).count()
         t_now = now()
         before_2d = t_now - timedelta(hours=48)
         before_2w = t_now - timedelta(days=14)
@@ -117,16 +125,17 @@ class StatusView(TemplateView):
         context['hosts_ipv6_2y'] = Host.objects.filter(last_update_ipv6__gt=before_2y).count()
         context['hosts_ipv4_ssl_2y'] = Host.objects.filter(last_update_ipv4__gt=before_2y, ssl_update_ipv4=True).count()
         context['hosts_ipv6_ssl_2y'] = Host.objects.filter(last_update_ipv6__gt=before_2y, ssl_update_ipv6=True).count()
-        context['users_total'] = User.objects.count()
-        context['users_active'] = User.objects.filter(is_active=True).count()
-        context['users_created_2d'] = User.objects.filter(date_joined__gt=before_2d).count()
-        context['users_loggedin_2d'] = User.objects.filter(last_login__gt=before_2d).count()
-        context['users_created_2w'] = User.objects.filter(date_joined__gt=before_2w).count()
-        context['users_loggedin_2w'] = User.objects.filter(last_login__gt=before_2w).count()
-        context['users_created_2m'] = User.objects.filter(date_joined__gt=before_2m).count()
-        context['users_loggedin_2m'] = User.objects.filter(last_login__gt=before_2m).count()
-        context['users_created_2y'] = User.objects.filter(date_joined__gt=before_2y).count()
-        context['users_loggedin_2y'] = User.objects.filter(last_login__gt=before_2y).count()
+        user_model = get_user_model()
+        context['users_total'] = user_model.objects.count()
+        context['users_active'] = user_model.objects.filter(is_active=True).count()
+        context['users_created_2d'] = user_model.objects.filter(date_joined__gt=before_2d).count()
+        context['users_loggedin_2d'] = user_model.objects.filter(last_login__gt=before_2d).count()
+        context['users_created_2w'] = user_model.objects.filter(date_joined__gt=before_2w).count()
+        context['users_loggedin_2w'] = user_model.objects.filter(last_login__gt=before_2w).count()
+        context['users_created_2m'] = user_model.objects.filter(date_joined__gt=before_2m).count()
+        context['users_loggedin_2m'] = user_model.objects.filter(last_login__gt=before_2m).count()
+        context['users_created_2y'] = user_model.objects.filter(date_joined__gt=before_2y).count()
+        context['users_loggedin_2y'] = user_model.objects.filter(last_login__gt=before_2y).count()
         return context
 
 
@@ -227,17 +236,17 @@ class DeleteHostView(DeleteView):
         return context
 
 
-class DomainOverwievView(CreateView):
+class DomainOverviewView(CreateView):
     model = Domain
     template_name = "main/domain_overview.html"
     form_class = CreateDomainForm
 
     @method_decorator(login_required)
     def dispatch(self, *args, **kwargs):
-        return super(DomainOverwievView, self).dispatch(*args, **kwargs)
+        return super(DomainOverviewView, self).dispatch(*args, **kwargs)
 
     def get_success_url(self):
-        return reverse('domain_overview')
+        return reverse('generate_ns_secret_view', args=(self.object.pk,))
 
     def form_valid(self, form):
         self.object = form.save(commit=False)
@@ -248,7 +257,7 @@ class DomainOverwievView(CreateView):
 
     def get_context_data(self, *args, **kwargs):
         context = super(
-            DomainOverwievView, self).get_context_data(*args, **kwargs)
+            DomainOverviewView, self).get_context_data(*args, **kwargs)
         context['nav_domain_overview'] = True
         context['your_domains'] = Domain.objects.filter(
             created_by=self.request.user)
@@ -312,6 +321,88 @@ class DeleteDomainView(DeleteView):
         return context
 
 
+class UpdaterHostConfigOverviewView(CreateView):
+    model = ServiceUpdaterHostConfig
+    template_name = "main/updater_hostconfig_overview.html"
+    form_class = CreateUpdaterHostConfigForm
+
+    @method_decorator(login_required)
+    def dispatch(self, *args, **kwargs):
+        self.__host_pk = kwargs.pop('pk', None)
+        return super(UpdaterHostConfigOverviewView, self).dispatch(*args, **kwargs)
+
+    def get_success_url(self):
+        return reverse('updater_hostconfig_overview', args=(self.__host_pk,))
+
+    def form_valid(self, form):
+        self.object = form.save(commit=False)
+        self.object.host = Host(pk=self.__host_pk)
+        self.object.created_by = self.request.user
+        self.object.save()
+        messages.add_message(self.request, messages.SUCCESS, 'Service Updater Host Configuration added.')
+        return HttpResponseRedirect(self.get_success_url())
+
+    def get_context_data(self, *args, **kwargs):
+        context = super(
+            UpdaterHostConfigOverviewView, self).get_context_data(*args, **kwargs)
+        context['updater_configs'] = ServiceUpdaterHostConfig.objects.filter(
+            host=self.__host_pk)
+        return context
+
+
+class UpdaterHostConfigView(UpdateView):
+    model = ServiceUpdaterHostConfig
+    template_name = "main/updater_hostconfig.html"
+    form_class = EditUpdaterHostConfigForm
+
+    @method_decorator(login_required)
+    def dispatch(self, *args, **kwargs):
+        return super(UpdaterHostConfigView, self).dispatch(*args, **kwargs)
+
+    def get_success_url(self):
+        host_pk = self.object.host.pk
+        return reverse('updater_hostconfig_overview', args=(host_pk,))
+
+    def form_valid(self, form):
+        self.object = form.save(commit=False)
+        self.object.save()
+        messages.add_message(self.request, messages.SUCCESS, 'Service Updater Host Configuration updated.')
+        return HttpResponseRedirect(self.get_success_url())
+
+    def get_object(self, *args, **kwargs):
+        obj = super(UpdaterHostConfigView, self).get_object(*args, **kwargs)
+        if obj.created_by != self.request.user:
+            raise PermissionDenied()  # or Http404
+        return obj
+
+    def get_context_data(self, *args, **kwargs):
+        context = super(UpdaterHostConfigView, self).get_context_data(*args, **kwargs)
+        return context
+
+
+class DeleteUpdaterHostConfigView(DeleteView):
+    model = ServiceUpdaterHostConfig
+    template_name = "main/delete_object.html"
+
+    @method_decorator(login_required)
+    def dispatch(self, *args, **kwargs):
+        return super(DeleteUpdaterHostConfigView, self).dispatch(*args, **kwargs)
+
+    def get_object(self, *args, **kwargs):
+        obj = super(DeleteUpdaterHostConfigView, self).get_object(*args, **kwargs)
+        if obj.created_by != self.request.user:
+            raise PermissionDenied()  # or Http404
+        return obj
+
+    def get_success_url(self):
+        host_pk = self.object.host.pk
+        return reverse('updater_hostconfig_overview', args=(host_pk,))
+
+    def get_context_data(self, *args, **kwargs):
+        context = super(DeleteUpdaterHostConfigView, self).get_context_data(*args, **kwargs)
+        return context
+
+
 class RobotsTxtView(View):
     """
     Dynamically serve robots.txt content.
