@@ -127,6 +127,7 @@ MIDDLEWARE_CLASSES = (
     'django.middleware.csrf.CsrfViewMiddleware',
     'django.contrib.auth.middleware.AuthenticationMiddleware',
     'django.contrib.messages.middleware.MessageMiddleware',
+    'social.apps.django_app.middleware.SocialAuthExceptionMiddleware',
     # Uncomment the next line for simple clickjacking protection:
     # 'django.middleware.clickjacking.XFrameOptionsMiddleware',
 )
@@ -253,8 +254,8 @@ SESSION_COOKIE_NAME = 'sessionid'
 SESSION_COOKIE_PATH = '/'
 SESSION_COOKIE_SECURE = False  # use True here if you have set WE_HAVE_SSL = True
 SESSION_COOKIE_HTTPONLY = True
-SESSION_COOKIE_AGE = 14 * 24 * 3600  # 2 weeks, in seconds (remember_me is True)
-SESSION_EXPIRE_AT_BROWSER_CLOSE = False  # more safe (remember_me is False)
+SESSION_COOKIE_AGE = 14 * 24 * 60 * 60  # 14 days, in seconds (remember_me is True)
+SESSION_EXPIRE_AT_BROWSER_CLOSE = True  # more safe (remember_me is False)
 
 SESSION_SERIALIZER = 'django.contrib.sessions.serializers.JSONSerializer'
 
@@ -278,7 +279,7 @@ SOCIAL_AUTH_LOGIN_REDIRECT_URL = '/'
 #    Used to redirect the user once the auth process ended successfully.
 #    The value of ?next=/foo is used if it was present
 
-#SOCIAL_AUTH_LOGIN_ERROR_URL = '/login-error/'
+SOCIAL_AUTH_LOGIN_ERROR_URL = '/accounts/login/'
 #    URL where the user will be redirected in case of an error
 
 SOCIAL_AUTH_LOGIN_URL = '/accounts/login/'
